{ pkgs, username, ... }:

{
  home.username = "${username}";
  home.homeDirectory = "/home/${username}";

  home.stateVersion = "24.05"; # Please read the comment before changing.

  home.packages = with pkgs; [
    eza
    jq
    htop
    ripgrep
    pavucontrol
    gnumake
    unzip
    gcc
    thunderbird
    keepassxc
    tree
    light
    element-desktop
    difftastic
    darktable
    kubectl
    kubectx
    simple-scan
    calibre
    libreoffice
    gthumb
    gimp
    evince
    screen
    inkscape
    chromium
    xclip
  ];

  # Home Manager can also manage your environment variables through
  # 'home.sessionVariables'. These will be explicitly sourced when using a
  # shell provided by Home Manager. If you don't want to manage your shell
  # through Home Manager then you have to manually source 'hm-session-vars.sh'
  # located at either
  #
  #  ~/.nix-profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  ~/.local/state/nix/profiles/profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  /etc/profiles/per-user/mandlm/etc/profile.d/hm-session-vars.sh
  #
  home.sessionVariables = { };

  programs.home-manager.enable = true;

  imports = [
    ./bat.nix
    ./carapace.nix
    ./direnv.nix
    ./firefox.nix
    ./fzf.nix
    ./git.nix
    ./gpg
    ./kitty.nix
    ./neovim
    ./nextcloud.nix
    ./starship.nix
    ./sway
    ./zoxide.nix
    ./zsh.nix
  ];
}
